/**
 * Ria_SourceTabs source code highlighter
 * Based on SimpleTabs Class
 * Required Prettify (http://code.google.com/p/google-code-prettify/) 
 * 
 * Simple and clean Source Tab plugin for MooTools 1.2
 * 
 * To use the Ajax feature simply use an anchor
 * with an href attribute as entry. The Ajax will
 * inject the response of this url into the tab.
 * 
 * Syntax highlighting is determined by the file extension
 * Now support 
 *   "bsh", "c", "cc", "cpp", "cs", "csh", "cyc", "cv", "htm", "html",
 *   "java", "js", "m", "mxml", "perl", "pl", "pm", "py", "rb", "sh",
 *   "xhtml", "xml", "xsl"
 *  	
 * If the file has a different file extension, the algorithm can be determined in
 * RiaSourceTabs.extensionTranslation
 * 
 * @example
 * 
 * RiaSourceTabs.extensionTranslation = {
 *     	'as'   : 'java',
 *      'wsdl' : 'xml'
 * }
 * var tabs = new RiaSourceTabs($('tab-element'), {
 * 		entrySelector: 'h2.tab-entry'
 * });
 * 
 * @version		1.0
 * 
 * @see			Events, Options
 * 
 * @requred     SimpleTabs
 * @requred     prettify (http://code.google.com/p/google-code-prettify/) 
 * @license		MIT License
 * @author		Oleg Cherniy <Oleg.Cherniy [at] google.com>
 * @copyright	2009 Author
 */

Request.Source = new Class({
	Extends: Request,
	
	success: function(text){
		this.onSuccess(text);
	}
});

var Ria_SourceTabs = new Class({
							  
	Extends: SimpleTabs,
	
	extensionsTranslation: {
		'as' : 'java'
	},

	/**
	 * Select the tab via tab-index
	 * 
	 * @param {Number} Tab-index
	 */
	select: function(index) {
		if (this.selected === index || !this.entries[index]) return this;
		var entry = this.entries[index];
		var params = [entry.toggle, entry.container, index];
		if (this.selected !== null) {
			var current = this.entries[this.selected];
			if (this.ajax && this.ajax.running) this.ajax.cancel();
			params.concat([current.toggle, current.container, this.selected]);
			this.fireEvent('onHide', [current.toggle, current.container, this.selected]);
		}
		var langExtension = this.langExtensionDetector(entry.url);
	
		this.fireEvent('onShow', params);
		if (entry.url && !entry.loaded) {
			this.ajax = new Request.Source({
				url: entry.url,	
				onRequest: this.fireEvent.pass(['onRequest', params], this),
				onFailure: this.fireEvent.pass(['onFailure', params], this),
				onComplete: function(resp) {
					entry.loaded = true;
					entry.container.empty().set('html', '<pre>' + prettyPrintOne(this.tagify(resp), langExtension) + '</pre>');
					this.fireEvent('onComplete', params);
				}.bind(this)
			}, this.options.ajaxOptions).get();
		}
		this.selected = index;
		return this;
	},
	
	langExtensionDetector: function(url) {
        var langExtension = url.match(/\.(\w+)$/);
		if (langExtension) { langExtension = langExtension[1]; }
		if (this.extensionsTranslation[langExtension] != undefined) {
			langExtension = this.extensionsTranslation[langExtension];
		}
		return langExtension;
	},
	
	tagify: function (string) {
		return string.replace(/[<]/g,'&lt;').replace(/[>]/g,'&gt;');
	}
});
